r37744 - in /trunk/liblog-handler-perl: ChangeLog META.yml debian/changelog lib/Log/Handler.pm lib/Log/Handler/Output/DBI.pm lib/Log/Handler/Output/Screen.pm

carnil-guest at users.alioth.debian.org carnil-guest at users.alioth.debian.org
Sun Jun 7 05:21:44 UTC 2009


Author: carnil-guest
Date: Sun Jun  7 05:20:31 2009
New Revision: 37744

URL: http://svn.debian.org/wsvn/pkg-perl/?sc=1&rev=37744
Log:
import the new changes

Modified:
    trunk/liblog-handler-perl/ChangeLog
    trunk/liblog-handler-perl/META.yml
    trunk/liblog-handler-perl/debian/changelog
    trunk/liblog-handler-perl/lib/Log/Handler.pm
    trunk/liblog-handler-perl/lib/Log/Handler/Output/DBI.pm
    trunk/liblog-handler-perl/lib/Log/Handler/Output/Screen.pm

Modified: trunk/liblog-handler-perl/ChangeLog
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/liblog-handler-perl/ChangeLog?rev=37744&op=diff
==============================================================================
--- trunk/liblog-handler-perl/ChangeLog (original)
+++ trunk/liblog-handler-perl/ChangeLog Sun Jun  7 05:20:31 2009
@@ -1,3 +1,12 @@
+0.56    Released at 2009-06-06.
+        - Just a full version.
+
+0.55_01 Released at 2009-06-05.
+        - Oops... there was no _raise_error routine in
+          Log::Handler::Output::Screen.
+        - Fixed a bug in Handler.pm - the hash reference that were
+          passed to add() were changed (RT #46631).
+
 0.54    Released at 2009-05-27.
         - Just a full version.
 

Modified: trunk/liblog-handler-perl/META.yml
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/liblog-handler-perl/META.yml?rev=37744&op=diff
==============================================================================
--- trunk/liblog-handler-perl/META.yml (original)
+++ trunk/liblog-handler-perl/META.yml Sun Jun  7 05:20:31 2009
@@ -1,6 +1,6 @@
 ---
 name: Log-Handler
-version: 0.54
+version: 0.56
 author:
   - Jonny Schulz
 abstract: Log messages to several outputs.
@@ -30,7 +30,7 @@
 provides:
   Log::Handler:
     file: lib/Log/Handler.pm
-    version: 0.54
+    version: 0.56
   Log::Handler::Config:
     file: lib/Log/Handler/Config.pm
     version: 0.04
@@ -54,7 +54,7 @@
     version: 0.02
   Log::Handler::Output::Screen:
     file: lib/Log/Handler/Output/Screen.pm
-    version: 0.02
+    version: 0.03
   Log::Handler::Output::Socket:
     file: lib/Log/Handler/Output/Socket.pm
     version: 0.05

Modified: trunk/liblog-handler-perl/debian/changelog
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/liblog-handler-perl/debian/changelog?rev=37744&op=diff
==============================================================================
--- trunk/liblog-handler-perl/debian/changelog (original)
+++ trunk/liblog-handler-perl/debian/changelog Sun Jun  7 05:20:31 2009
@@ -1,3 +1,9 @@
+liblog-handler-perl (0.56-1) UNRELEASED; urgency=low
+
+  * New upstream release
+
+ -- Salvatore Bonaccorso <salvatore.bonaccorso at gmail.com>  Sun, 07 Jun 2009 07:17:55 +0200
+
 liblog-handler-perl (0.54-2) UNRELEASED; urgency=low
 
   * debian/watch: Update to ignore development releases.

Modified: trunk/liblog-handler-perl/lib/Log/Handler.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/liblog-handler-perl/lib/Log/Handler.pm?rev=37744&op=diff
==============================================================================
--- trunk/liblog-handler-perl/lib/Log/Handler/Output/DBI.pm (original)
+++ trunk/liblog-handler-perl/lib/Log/Handler/Output/DBI.pm Sun Jun  7 05:20:31 2009
@@ -171,7 +171,7 @@
 
 =item B<reconnect>
 
-C<reconnect> is deprecated!
+C<reconnect> is deprecated and not usable!
 
 =item B<dbi_params>
 

Modified: trunk/liblog-handler-perl/lib/Log/Handler/Output/Screen.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/liblog-handler-perl/lib/Log/Handler/Output/Screen.pm?rev=37744&op=diff
==============================================================================
--- trunk/liblog-handler-perl/lib/Log/Handler/Output/Screen.pm (original)
+++ trunk/liblog-handler-perl/lib/Log/Handler/Output/Screen.pm Sun Jun  7 05:20:31 2009
@@ -87,7 +87,7 @@
 use Data::Dumper;
 use Params::Validate;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our $ERRSTR  = '';
 
 sub new {
@@ -141,4 +141,10 @@
     return \%options;
 }
 
+sub _raise_error {
+    my $self = shift;
+    $ERRSTR = shift;
+    return undef;
+}
+
 1;




More information about the Pkg-perl-cvs-commits mailing list
--- trunk/liblog-handler-perl/lib/Log/Handler.pm (original)
+++ trunk/liblog-handler-perl/lib/Log/Handler.pm Sun Jun  7 05:20:31 2009
@@ -1032,7 +1032,7 @@
 use Log::Handler::Pattern;
 use base qw(Log::Handler::Levels);
 
-our $VERSION = '0.54';
+our $VERSION = '0.56';
 our $ERRSTR  = '';
 
 # $TRACE and $CALLER_LEVEL are both used as global
@@ -1371,9 +1371,9 @@
 # private stuff
 #
 
-sub _shift_options {
-    my ($self, $output_opts) = @_;
-    my %handler_opts;
+sub _split_options {
+    my ($self, $opts) = @_;
+    my (%handler_opts, %output_opts);
 
     # It's possible to pass all options for the handler and for the
     # output to add(). These options must be splitted. The options
@@ -1381,7 +1381,7 @@
     # options for the output will be passed - as example - to
     # Log::Handler::Output::File.
 
-    my @shift_options = qw(
+    my %split_options = map { $_ => 0 } qw(
         alias
         debug_mode
         debug_skip
@@ -1401,12 +1401,15 @@
         timeformat
     );
 
-    foreach my $opt ( @shift_options ) {
-        next unless exists $output_opts->{$opt};
-        $handler_opts{$opt} = delete $output_opts->{$opt};
-    }
-
-    return \%handler_opts;
+    while (my ($k, $v) = each %$opts) {
+        if (exists $split_options{$k}) {
+            $handler_opts{$k} = $v;
+        } else {
+            $output_opts{$k} = $v;
+        }
+    }
+
+    return (\%handler_opts, \%output_opts);
 }
 
 sub _new_output {
@@ -1414,7 +1417,7 @@
     my $type    = shift;
     my $args    = @_ > 1 ? {@_} : shift;
     my $package = ref($type);
-    my ($output, $handler_opts);
+    my ($output, $handler_opts, $output_opts);
 
     # There are two ways to add an output:
     #
@@ -1431,9 +1434,8 @@
         $output = $type;
         $handler_opts = $args;
     } else {
-        # Shift the handler options from $args. The rest in %$args
-        # will be passed to the output.
-        $handler_opts = $self->_shift_options($args);
+        # Split the handler and output options from $args.
+        ($handler_opts, $output_opts) = $self->_split_options($args);
 
         # Try to determine which output is wanted...
         if (exists $AVAILABLE_OUTPUTS{$type}) {
@@ -1445,7 +1447,8 @@
         }
 
         $package->require;
-        $output = $package->new($args) or Carp::croak $package->errstr;
+        $output = $package->new($output_opts)
+            or Carp::croak $package->errstr;
     }
 
     $handler_opts = $self->_validate_options($handler_opts);

Modified: trunk/liblog-handler-perl/lib/Log/Handler/Output/DBI.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/liblog-handler-perl/lib/Log/Handler/Output/DBI.pm?rev=37744&op=diff
==============================================================================